@@ -68,6 +68,10 @@ class Client:
         except:
             raise Exception("Unable to hook; is VALORANT running?")
 
+    def fetch_regions(self) -> list:
+        '''Fetch valid regions'''
+        return regions
+
     def fetch(self, endpoint="/", endpoint_type="pd") -> dict:
         '''Get data from a pd/glz/local endpoint'''
         if endpoint_type == "pd" or endpoint_type == "glz":
